#!/bin/bash -x

# remove all existing shield tracker connections
pw-link -I -l | awk '/\|<-.*shield_tracker/ { print $1; }' | xargs -n1 pw-link -d

# connect all midi bridge outputs to stracker midi input
pw-link -o \
| grep -E '^Midi-Bridge:' \
| grep -v '^Midi-Bridge:Midi Through' \
| while read midi_port
do
	echo $midi_port
	pw-link "${midi_port}" "shield_tracker:midi_in_1"
done

# connect stracker midi output port 0 to all system midi outputs
pw-link -i \
| grep -E '^Midi-Bridge:' \
| grep -v 'mioXL Preset Selector' \
| while read midi_port
do
	echo $midi_port
	pw-link "shield_tracker:midi_out_1" "${midi_port}"
done

# connect midi output to yoshimi soft synth
pw-link "shield_tracker:midi_out_1" "yoshimi:midi in"

# connect stracker audio output ports to external audio interface
port_num=1
pw-link -i \
| grep -E '^alsa_output.*:playback_AUX.*' \
| while read audio_output
do
	pw-link "shield_tracker:output_${port_num}" "${audio_output}"
	port_num=$(( $port_num + 1 ))
done

# connect external audio interface inputs to stracker
port_num=1
pw-link -o \
| grep -E '^alsa_input.*:capture_AUX.*' \
| while read audio_input
do
	pw-link "${audio_input}" "shield_tracker:input_${port_num}"
	port_num=$(( $port_num + 1 ))
done

check_output_connected() {
	x=$(pw-link -l | sed -n '/^'"${1}"'$/{n;p;}')
	[[ "${x}" ]]
}

check_output_connected "shield_tracker:output_1" || pw-link "shield_tracker:output_1" "input.virtual-sink:playback_FL"
check_output_connected "shield_tracker:output_2" || pw-link "shield_tracker:output_2" "input.virtual-sink:playback_FR"


pa_default_sink=$(pactl get-default-sink)

check_output_connected "shield_tracker:output_1" || pw-link "shield_tracker:output_1" "${pa_default_sink}:playback_FL"
check_output_connected "shield_tracker:output_2" || pw-link "shield_tracker:output_2" "${pa_default_sink}:playback_FR"

